﻿using System;
using System.Linq;
using System.ComponentModel;
using System.Collections.ObjectModel;


namespace SampleForSupport
{

    /// <summary>
    /// View Model de l'ecran des défauts équipements
    /// </summary>
    public class MeterDefectsViewModel : ViewModelBase
    {
        #region Attributs

        ObservableCollection<DefectReadingMeterSynthesis> matchedDefectsSynthesis;
        ObservableCollection<DateTime> daysInPeriod;


        DateTime beginDate = new DateTime(2012, 02, 01);
        DateTime endDate = new DateTime(2012, 02, 05);

        #endregion

        #region Properties


        static PropertyChangedEventArgs matchedDefectsSynthesisChangeArgs = new PropertyChangedEventArgs("MatchedDefectsSynthesis");

        /// <summary>
        /// Liste des défauts affichés
        /// </summary>
        public ObservableCollection<DefectReadingMeterSynthesis> MatchedDefectsSynthesis
        {
            get
            {
                return matchedDefectsSynthesis;
            }

            set
            {
                matchedDefectsSynthesis = value;
                NotifyPropertyChanged(matchedDefectsSynthesisChangeArgs);
            }
        }

        static PropertyChangedEventArgs daysInPeriodArgs = new PropertyChangedEventArgs("DaysInPeriod");

        /// <summary>
        /// Liste des jours dans la période sélectionnée dans le filtre
        /// </summary>
        public ObservableCollection<DateTime> DaysInPeriod
        {
            get
            {
                return daysInPeriod;
            }

            set
            {
                daysInPeriod = value;
                NotifyPropertyChanged(daysInPeriodArgs);
            }
        }






        static PropertyChangedEventArgs beginDateChangeArgs = new PropertyChangedEventArgs("BeginDate");

        /// <summary>
        /// Date de début
        /// </summary>
        public DateTime BeginDate
        {
            get
            {
                return beginDate;
            }

            set
            {
                beginDate = value;
                NotifyPropertyChanged(beginDateChangeArgs);
            }
        }

        static PropertyChangedEventArgs endDateChangeArgs = new PropertyChangedEventArgs("EndDate");

        /// <summary>
        /// Date de fin
        /// </summary>
        public DateTime EndDate
        {
            get
            {
                return endDate;
            }

            set
            {
                endDate = value;
                NotifyPropertyChanged(beginDateChangeArgs);
                NotifyPropertyChanged(endDateChangeArgs);
            }
        }

        #endregion


        #region Constructor

        /// <summary>
        /// Constructeur
        /// </summary>
        public MeterDefectsViewModel()
        {
            ObservableCollection<DateTime> myDateList = new ObservableCollection<DateTime>();
            foreach (DateTime d in Enumerable.Range(0, (this.EndDate - this.BeginDate).Days)
                                                        .Select(value => this.BeginDate.AddDays(value)))
            {
                myDateList.Add(d);
            }

            this.DaysInPeriod = myDateList;


            ObservableCollection<DefectReadingMeterSynthesis> myList = new ObservableCollection<DefectReadingMeterSynthesis>();
            DefectReadingMeterSynthesis tmp = new DefectReadingMeterSynthesis();
            tmp.DefectCode = "ABC";
            tmp.MeterId = 123;
            tmp.DefectMeterByDay = new System.Collections.Generic.List<string>() { " ", "x", " ", " ", "x" };
            tmp.DefectMeterNbOccurences = 2;

            myList.Add(tmp);

            DefectReadingMeterSynthesis tmp2 = new DefectReadingMeterSynthesis();
            tmp2.DefectCode = "ABD";
            tmp2.MeterId = 333;
            tmp2.DefectMeterByDay = new System.Collections.Generic.List<string>() { "x", "x", " ", "x", "x" };
            tmp2.DefectMeterNbOccurences = 4;

            myList.Add(tmp2);


            this.MatchedDefectsSynthesis = myList;
        }


        #endregion

        



    }
}


